SubcommandError

Struct SubcommandError 

pub struct SubcommandError { /* private fields */ }
Error returned when subcommand dispatch cannot select a command.

Implementations

Source

impl SubcommandError

pub fn missing(expected: Vec<String>) -> Self

Create a missing-subcommand error.

pub fn unknown(command: String, expected: Vec<String>) -> Self

Create an unknown-subcommand error.

pub fn command(&self) -> Option<&str>

Return the unknown subcommand, or None when no subcommand was provided.

pub fn expected(&self) -> &[String]

Return the expected command names.